@@ -1,5 +1,6 @@
 #' Plot a `dataquieR` summary
 #'
+#' @inheritParams util_filter_repsum
 #' @param x the `dataquieR` summary, see [summary()] and [dq_report2()]
 #' @param y not yet used
 #' @param ... not yet used
@@ -8,16 +9,24 @@
 #' @param dont_plot suppress the actual plotting, just return a printable
 #'                   object derived from `x`
 #' @param stratify_by column to stratify the summary, may be one string.
+#' @param disable_plotly [logical] do not use `plotly`, even if installed
 #'
 #' @return invisible html object
 #' @export
 #'
 plot.dataquieR_summary <- function(x, y, ..., filter, dont_plot = FALSE,
-                                   stratify_by) {
+                                   stratify_by,
+                                   vars_to_include = "study",
+                                   disable_plotly = FALSE) {
+  if (!disable_plotly) {
+    util_ensure_suggested(pkg = c("plotly"),
+                          goal = "generate interactive HTML-summaries.")
+  }
+
   util_stop_if_not("y is not used for plotting summaries" = missing(y))
   util_ensure_suggested(pkg = c("htmltools",
-                                "digest", "DT", "rmarkdown",
-                                "markdown", "plotly"),
+                                "DT", "rmarkdown",
+                                "markdown"),
                         goal = "generate plain HTML-summaries.")
 
   x <- util_reclassify_dataquieR_summary(x)
@@ -33,6 +42,13 @@ plot.dataquieR_summary <- function(x, y, ..., filter, dont_plot = FALSE,
   }
   this <- attr(repsum, "this")
 
+  suitable_vars_sum <- util_filter_repsum(this$result,
+                                          vars_to_include,
+                                          this$meta_data,
+                                          this$rownames_of_report,
+                                          this$label_col)
+  rownames_of_report <- attr(suitable_vars_sum, "rownames_of_report")
+
   # suppressMessages(this$result %>%
   #                    dplyr::filter(!startsWith(as.character(indicator_metric), "CAT_")) %>%
   #                    dplyr::filter(!startsWith(as.character(indicator_metric), "MSG_")) %>%
@@ -41,7 +57,7 @@ plot.dataquieR_summary <- function(x, y, ..., filter, dont_plot = FALSE,
   #                    dplyr::summarise(value = length(function_name)) ->
   #                    summ_per_fkt_fig)
 
-  suppressMessages(this$result %>%
+  suppressMessages(suitable_vars_sum %>%
                      dplyr::filter(!startsWith(as.character(indicator_metric), "CAT_")) %>%
                      dplyr::filter(!startsWith(as.character(indicator_metric), "MSG_")) ->
                      all_per_variable_all_issue_classes_except_errors)
@@ -97,7 +113,7 @@ plot.dataquieR_summary <- function(x, y, ..., filter, dont_plot = FALSE,
       dplyr::mutate(X =
                       sprintf(
                         "%d variables: %d classified by indicators",
-                        length(this$rownames_of_report),
+                        length(rownames_of_report),
                         length(unique(plot_tab$VAR_NAMES))
                       ),
                     class = as.integer(class)) ->
@@ -115,12 +131,22 @@ plot.dataquieR_summary <- function(x, y, ..., filter, dont_plot = FALSE,
   #  sum_worst_per_variable$note <-
 
 #  if (length(unique(sum_plot_tab$X)) > 0) {
+  if (!disable_plotly) {
     summaryplots <-
-      prep_render_pie_chart_from_summaryclasses_plotly(sum_plot_tab,
-                                                       meta_data = this$meta_data)
+      prep_render_pie_chart_from_summaryclasses_plotly(
+        sum_plot_tab,
+        meta_data = this$meta_data
+      )
+  } else {
+    summaryplots <-
+      prep_render_pie_chart_from_summaryclasses_ggplot2(
+        sum_plot_tab,
+        meta_data = this$meta_data
+      )
+  }
   # } else {
   #   summaryplots <- htmltools::tags$p(sprintf(
-  #     "None of the %d variables was classified", length(this$rownames_of_report)))
+  #     "None of the %d variables was classified", length(rownames_of_report)))
   # }
 
   if (!inherits(summaryplots, "htmlwidget") &&
