@@ -6,16 +6,16 @@
 #'
 #' @family system_functions
 #' @concept process
-#' @keywords internal
+#' @noRd
 util_detect_cores <- function() {
   if (requireNamespace("parallelly", quietly = TRUE)) {
     return(parallelly::availableCores())
-  } else if (requireNamespace("rJava", quietly = TRUE)) {
-    rJava::.jinit()
-    rt <- rJava::.jcall("java/lang/Runtime", "Ljava/lang/Runtime;",
-                        method = "getRuntime")
-    cpus <- rJava::.jcall(rt, "I", "availableProcessors")
-    return(cpus)
+  # } else if (requireNamespace("rJava", quietly = TRUE)) {
+  #   rJava::.jinit()
+  #   rt <- rJava::.jcall("java/lang/Runtime", "Ljava/lang/Runtime;",
+  #                       method = "getRuntime")
+  #   cpus <- rJava::.jcall(rt, "I", "availableProcessors")
+  #  return(cpus)
   } else if (requireNamespace("parallel", quietly = TRUE)) {
     r <- parallel::detectCores()
     if (length(r) != 1 || is.na(r) || !util_is_integer(r) || r < 1) {
@@ -28,8 +28,8 @@ util_detect_cores <- function() {
                    "using default of 1 core only."),
                  util_pretty_vector_string(c(
                    "parallel",
-                   "parallelly",
-                   "rJava")))
+                   "parallelly")))#,
+                   #"rJava")))
     return(1)
   }
 }
