@@ -40,6 +40,7 @@
 #'                     geom_count aes geom_vline geom_hline
 #' @import patchwork
 #'
+#' @noRd
 util_margins_lm <- function(resp_vars = NULL, group_vars = NULL, co_vars = NULL,
                             threshold_type = NULL, threshold_value,
                             min_obs_in_subgroup = 5, ds1, label_col,
@@ -170,103 +171,182 @@ util_margins_lm <- function(resp_vars = NULL, group_vars = NULL, co_vars = NULL,
   }
 
   # Plot 1: hybrid density/boxplot graph
-  p1 <- ggplot(data = ds1[, c("resp_var_adj", group_vars), drop = FALSE],
-               aes(x = .data[[group_vars]], y = .data[["resp_var_adj"]]))
-  if (show_violins) {
-    p1 <- p1 + geom_violin(alpha = 0.9, draw_quantiles = TRUE, fill = "gray99")
+  .ds00 <- ds1[, c("resp_var_adj", group_vars), drop = FALSE]
+  if (all(!is.finite(.ds00$resp_var_adj))) {
+    util_error("No data left.")
   }
-  p1 <- p1 +
-    geom_boxplot(width = 0.1, fill = "white", color = "gray", alpha = 0.5) +
-    geom_pointrange(
-      data = res_df, aes(
-        x = factor(.data[[group_vars]]),
-        y = margins,
-        ymin = LCL,
-        ymax = UCL,
-        color = as.factor(GRADING)#, n = sample_size
-      ),
-      shape = 18, linewidth = 1,
-      inherit.aes = FALSE,
-      fatten = 5
-    ) +
-    theme_minimal() +
-    labs(x = "", y = "") +
-    theme(
-      legend.position = "none", legend.title = element_blank(),
-      text = element_text(size = 16),
-      axis.text.x = element_text(angle = 90, vjust = 0.5, hjust = 1)
-    ) +
-    scale_colour_manual(values = warn_code)
+  p1 <-
+    util_create_lean_ggplot(ggplot(data = .ds00,
+                                   aes(x = .data[[group_vars]],
+                                       y = .data[["resp_var_adj"]])),
+                            .ds00 = .ds00,
+                            group_vars = group_vars)
+  if (show_violins) {
+    p1 <- util_create_lean_ggplot(p1 +
+                                    geom_violin(alpha = 0.9,
+                                                fill = "gray99") +
+                                    ggplot2::stat_ydensity( # FIXME: ggplot2 4.0.0 now draws actual data quantiles (not “density-inferred” ones), so the lines may shift very slightly compared to pre-4.0.0 outputs, but the intent (e.g., median at 0.5) is the same. ggplot2.tidyverse.org   -- do we need to change some documentation?
+                                      geom = "violin",
+                                      alpha = 0.9,
+                                      fill  = "gray99",
+                                      quantiles = 0.5
+                                    ),
+                                  p1 = p1)
+  }
+  p1 <- util_create_lean_ggplot(p1 +
+                                  geom_boxplot(width = 0.1,
+                                               fill = "white",
+                                               color = "gray",
+                                               alpha = 0.5) +
+                                  geom_pointrange(
+                                    data = res_df, aes(
+                                      x = factor(.data[[group_vars]]),
+                                      y = margins,
+                                      ymin = LCL,
+                                      ymax = UCL,
+                                      color = as.factor(GRADING)#, n = sample_size
+                                    ),
+                                    shape = 18,
+                                    linewidth = 1,
+                                    inherit.aes = FALSE,
+                                    size = .5) +
+                                  theme_minimal() +
+                                  labs(x = "", y = "") +
+                                  theme(
+                                    legend.position = "none",
+                                    legend.title = element_blank(),
+                                    text = element_text(size = 16),
+                                    axis.text.x = element_text(angle = 90,
+                                                               vjust = 0.5,
+                                                               hjust = 1)
+                                  ) +
+                                  scale_colour_manual(values = warn_code),
+                                p1 = p1,
+                                res_df = res_df,
+                                group_vars = group_vars,
+                                warn_code = warn_code)
 
   if (include_numbers_in_figures) {
-    p1 <- p1 +
-      geom_text(data = summary_ds,
-                aes(x = summary_ds[, group_vars],
-                    y = max(ds1[, "resp_var_adj", drop = FALSE]) + 1.2,
-                    label = sample_size),
-                hjust = 0.5, angle = 90) +
-      annotate("text",
-               x = 0.5,
-               y = max(ds1[, "resp_var_adj", drop = FALSE]) + 1.2,
-               label = "N")
+    .ds01 <- summary_ds[, group_vars]
+    .ds02 <- ds1[, "resp_var_adj", drop = FALSE]
+    p1 <- util_create_lean_ggplot(p1 +
+                                    geom_text(data = summary_ds,
+                                              aes(x = .ds01,
+                                                  y = max(.ds02) + 1.2,
+                                                  label = sample_size),
+                                              hjust = 0.5, angle = 90) +
+                                    annotate("text",
+                                             x = 0.5,
+                                             y = max(.ds02) + 1.2,
+                                             label = "N"),
+                                  p1 = p1,
+                                  summary_ds = summary_ds,
+                                  .ds01 = .ds01,
+                                  .ds02 = .ds02
+    )
   }
 
   if (!is.null(levels)) {
-    try(p1 <- p1 + ggplot2::scale_y_continuous(breaks =
-                                                  as.integer(names(levels)),
-                                                labels = levels), silent = TRUE)
+    try(p1 <-
+          util_create_lean_ggplot(
+            p1 +
+              ggplot2::scale_y_continuous(breaks =
+                                            as.integer(names(levels)),
+                                          labels = levels),
+            p1 = p1,
+            levels = levels),
+        silent = TRUE)
   }
 
   if (threshold_type != "none") {
-    p1 <- p1 +
-      geom_hline(yintercept = pars[2], color = "red") +
-      geom_hline(yintercept = pars[-2], color = "red", linetype = 2)
+    p1 <- util_create_lean_ggplot(p1 +
+                                    geom_hline(yintercept = pars[2],
+                                               color = "red") +
+                                    geom_hline(yintercept = pars[-2],
+                                               color = "red",
+                                               linetype = 2),
+                                  p1 = p1,
+                                  pars = pars)
   } else {
-    p1 <- p1 +
-      geom_hline(yintercept = pars[2], color = "red")
+    p1 <- util_create_lean_ggplot(p1 +
+                                    geom_hline(yintercept = pars[2],
+                                               color = "red"),
+                                  p1 = p1,
+                                  pars = pars)
   }
 
   # Plot 2: overall distributional plot flipped on y-axis of plot 1
-  get_y_scale <- ggplot(ds1[, "resp_var_adj", drop = FALSE],
-                        aes(x = .data[["resp_var_adj"]])) +
-    geom_density(alpha = 0.35)
-  aty <- mean(range(ggplot_build(get_y_scale)$data[[1]]$y))
+  .ds03 <- ds1[, "resp_var_adj", drop = FALSE]
+  get_y_scale <- util_create_lean_ggplot(
+    ggplot(.ds03,
+           aes(x = .data[["resp_var_adj"]])) +
+      geom_density(alpha = 0.35),
+    .ds03 = .ds03)
 
-  p2 <- ggplot(ds1[, "resp_var_adj", drop = FALSE],
-               aes(.data[["resp_var_adj"]])) +
-    geom_density(alpha = 0.35) +
-    coord_flip() +
-    theme_minimal() +
-    labs(x = NULL, y = NULL) +
-    ggplot2::xlim(c(min(min(ds1[, "resp_var_adj", drop = FALSE]), pars),
-                    max(max(ds1[, "resp_var_adj", drop = FALSE]) + 1.2,
-                        pars + offs))) +
-    theme(axis.text.y = element_blank(), axis.text.x = element_blank(),
-          text = element_text(size = 16))
+  build <- ggplot2::ggplot_build(get_y_scale)
+  data1 <- util_gg_get(build, "data")[[1]]
+  yvals <- util_gg_get(data1, "y")
+
+  aty <- mean(range(yvals))
+
+
+  p2 <- util_create_lean_ggplot(ggplot(.ds03,
+                                       aes(.data[["resp_var_adj"]])) +
+                                  geom_density(alpha = 0.35) +
+                                  coord_flip() + # util_lazy_add_coord(p, fli)
+                                  theme_minimal() +
+                                  labs(x = NULL, y = NULL) +
+                                  ggplot2::xlim(c(min(min(.ds03), pars),
+                                                  max(max(.ds03) + 1.2,
+                                                      pars + offs))) +
+                                  theme(axis.text.y = element_blank(),
+                                        axis.text.x = element_blank(),
+                                        text = element_text(size = 16)),
+                                .ds03 = .ds03,
+                                pars = pars,
+                                offs = offs)
 
   if (threshold_type != "none") {
-    p2 <-
+    p2 <- util_create_lean_ggplot(
       p2 +
-      annotate(geom = "text", x = pars + offs, y = aty, label = parn) +
-      geom_vline(xintercept = pars[2], color = "red") +
-      geom_vline(xintercept = pars[-2], color = "red", linetype = 2)
+        annotate(geom = "text",
+                 x = pars + offs,
+                 y = aty,
+                 label = parn) +
+        geom_vline(xintercept = pars[2], color = "red") +
+        geom_vline(xintercept = pars[-2], color = "red", linetype = 2),
+      p2 = p2,
+      pars = pars,
+      offs = offs,
+      aty = aty,
+      parn = parn)
   } else {
-    p2 <-
+    p2 <- util_create_lean_ggplot(
       p2 +
-      annotate(geom = "text", x = pars + offs, y = aty,
-               label = c("", parn[2], "")) +
-      geom_vline(xintercept = pars[2], color = "red")
+        annotate(geom = "text",
+                 x = pars + offs,
+                 y = aty,
+                 label = c("", parn[2], "")) +
+        geom_vline(xintercept = pars[2], color = "red"),
+      p2 = p2,
+      pars = pars,
+      offs = offs,
+      aty = aty,
+      parn = parn)
   }
-
   # combine plots and add the title
   res_plot <- # TODO: For all patchwork-calls, add information to reproduce the layout in plot.ly
-    p1 +
-    p2 +
-    plot_layout(nrow = 1,
-                widths = c(5, 1)
-    ) +
-    plot_annotation(title = title,
-                    subtitle = adjusted_hint)
+    util_create_lean_ggplot(
+      p1 +
+        p2 +
+        plot_layout(nrow = 1,
+                    widths = c(5, 1)) +
+        plot_annotation(title = title,
+                        subtitle = adjusted_hint),
+      p1 = p1,
+      p2 = p2,
+      title = title,
+      adjusted_hint = adjusted_hint)
 
   # output ---------------------------------------------------------------------
   return(list("plot_data" = res_df, "plot" = res_plot))
