@@ -1,7 +1,7 @@
 test_that("util_looks_like_missing works", {
   skip_on_cran()
   expected <- rep(FALSE, 100)
-  expected[c(88, 89, 98, 99)] <- TRUE
+  #expected[c(88, 89, 98, 99)] <- TRUE
   expect_equal(
     util_looks_like_missing(1:100, n_rules = 0),
     expected = expected
